local agent_helper = require("scripts/agent/agent_helper")

AgentAdapter = {
	is_init = false,
	login_callback = nil,
	force_logout = false,
	is_login_verify_ing = false,
	login_verify_url = "cls.cq26.3hgame.com/af1/login_verify.php",
	pay_callback_url = "http://cls.cq26.3hgame.com/af1/pay.php",
	uid = "",
	is_shieldingPay = false,
}

function PlatformAdapter:OpenExitDialog()
	agent_helper:Exit(function(result)
		if result == "true" then
			AdapterToLua:endGame()
		else
			local format = { title = "退出", message = "退出游戏?", positive = "确定", negative = "取消", }
			PlatformAdapter:OpenAlertDialog(format, 
			function (result) 
				if "positive" == result then 
					PlatformBinder:JsonCall("call_agent_exit", "true", "", function(result) AdapterToLua:endGame() end)
				end 
			end)
		end			
	end)
end

-- 初始化
function AgentAdapter:Init()
	if self.is_init then return end

	local cache_data = Split((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), "_")
	if cache_data ~= nil then
		GLOBAL_CONFIG.package_info.config.agent_id = AdapterToLua:getInstance():getDataCache("af1_channeld") or "af1"
		self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), "afy_", "")
	end
	self.is_init = true
	AgentMs:InitLocalPush()

	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "af1"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "afy_" .. self.uid
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return "神兵风云豪华版"
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "agentres/logo.png"
end

function AgentAdapter:LoginCallback(result)
	local json_obj = cjson.decode(result)
	local sdk = json_obj.sdk
	
	Log("渠道ID========="..sdk)

	local verify_callback = function(url, arg, data, size)
		self.is_login_verify_ing = false
		if size <= 0 then
			Log("verify_callback, fail:size<=0")
			return
		end
		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			Log("verify_callback, fail")
			return
		end
		self.uid = ret_t.user.uid
		self.is_shieldingPay = ret_t.user.is_shieldingPay
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())
	end

	self.is_login_verify_ing = true
	local device = tostring(PlatformAdapter.GetPhoneUniqueId())
	local real_url = string.format("%s?spid=%s&uid=%s&token=%s&device=%s&sdk=%s", self.login_verify_url, self:GetSpid(), json_obj.uid, json_obj.token, device, sdk)
	Log("start verify login: url=" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)
end

function AgentAdapter:Login(callback)
	self.login_callback = callback
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))
end

function AgentAdapter:LogoutCallback(result)
	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
	return true
end

function AgentAdapter:Logout()
	agent_helper:Logout()
end

function AgentAdapter:OnClickBackLogin()
	agent_helper:Logout()
end

function AgentAdapter:OnClickRestartGame()
	agent_helper:Logout()	
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)
	if self.is_shieldingPay == true then
		SysMsgCtrl.Instance:ErrorRemind("充值失败，请联系游戏客服")
		return
	end

	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()
	if role_vo ~= nil and user_vo ~= nil then
		local info = {}
		info.server_id = tostring(server_id)
		info.server_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
		info.role_name = role_name
		info.role_id = tostring(role_id)
		info.user_level = tostring(role_vo[OBJ_ATTR.CREATURE_LEVEL]) or "0"
		info.vip_level = tostring(role_vo[OBJ_ATTR.ACTOR_VIP_GRADE]) or "0"

		if RoleData.Instance and RoleData.Instance.role_info then
			info.gold =  role_vo[OBJ_ATTR.ACTOR_GOLD] or "0"
			info.party_name = RoleData.Instance.role_vo.guild_name or ""
		else
			info.gold = "0"
			info.party_name = ""
		end

		info.order_id = server_id .. "_" .. self.GetSpid() .. "_" ..self.uid .. "_" .. os.time().. "_" .. role_id
		info.goods_id = "1"
		info.goods_name = "元宝"
		info.goods_desc = amount * 800 .. "元宝"
		info.quantifier = "个"
		info.count = amount * 800
		info.price = 0.00125
		info.amount = amount
		info.callback_url = self.pay_callback_url
		info.extras = order_id

		print(cjson.encode(info))
		agent_helper:Pay(cjson.encode(info), callback)
	end
	
end

-- 创建角色上报
function AgentAdapter:ReportOnCreateRole(role_name)
	self:SubmitInfo(0)
end

-- 进入游戏上报
function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(1)
end

--  升级上报
function AgentAdapter:ReportOnRoleLevUp(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(2)
end


function AgentAdapter:SubmitInfo(type)
	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()

	if role_vo ~= nil and user_vo ~= nil then
		local info = {}
		info.server_id = tostring(user_vo.plat_server_id)
		info.server_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
		info.role_name = role_vo.name
		info.role_id = tostring(user_vo.cur_role_id)
		info.user_level =  tostring(role_vo[OBJ_ATTR.CREATURE_LEVEL]) or "0"
		info.vip_level = tostring(role_vo[OBJ_ATTR.ACTOR_VIP_GRADE]) or "0"
		info.RoleCreateTime = tostring(role_vo.create_time) or "0"
		if RoleData.Instance and RoleData.Instance.role_info then
			info.gold = role_vo[OBJ_ATTR.ACTOR_GOLD] or "0"
			info.party_name = RoleData.Instance.role_vo.guild_name or ""
		else
			info.gold = "0"
			info.party_name = ""
		end
		info.sub_type = type

		print(cjson.encode(info))
		PlatformBinder:JsonCall("send_user_info", cjson.encode(info))
	end
end

-- 是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end

-- 分渠道  特殊处理
-- function AgentAdapter:SetChanneId(channeld)
-- 	--商务特殊需求，不给上的渠道
-- 	local list = {}
-- 	GLOBAL_CONFIG.package_info.config.agent_id = channelIds[tostring(channeld)] or "af1"
-- 	AdapterToLua:getInstance():setDataCache("af1_channeld", GLOBAL_CONFIG.package_info.config.agent_id)
-- 	if GLOBAL_CONFIG.package_info.config.agent_id == "af1" then
-- 		SysMsgCtrl.Instance:ErrorRemind("正在使用母包标识，需要通知cp添加子渠道标识", true)
-- 	else
-- 		if not list then
--        		return false   
-- 	    end 
-- 	        if list then
-- 	           for k, v in pairs(list) do
-- 	               if v ==GLOBAL_CONFIG.package_info.config.agent_id then
-- 	                  AdapterToLua:endGame()
-- 	               end
-- 	           end
-- 	        end
-- 	end

-- end
