local agent_helper = require("scripts/agent/agent_helper")


AgentAdapter = {
	is_init = false,
	is_login_verify_ing = false,
	login_callback = nil,
	force_logout = false,
    login_verify_url = "cls.cq21.gzwynet.com/lqu/login_verify.php",
    pay_verify_url = "http://cls.cq21.gzwynet.com/lqu/pay.php",
	uid = "",
}

-- 初始化
function AgentAdapter:Init()

	if self.is_init then return end
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), "aqu_", "")
	self.is_init = true
	AgentMs:InitLocalPush()
	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "lqu"
end
-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "aqu_" .. self.uid
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return "遮天重置版"
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "agentres/logo.png"
end

function AgentAdapter:Login(callback)
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end
	self.login_callback = callback
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))--设置登陆回调 

end

function AgentAdapter:OnClickBackLogin()
	PlatformBinder:JsonCall("call_agent_logout", "")
end

function AgentAdapter:OnClickRestartGame()
	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	PlatformBinder:JsonCall("call_agent_logout", role_vo.role_name)
end

function AgentAdapter:LoginCallback(result)
	
	local json_obj = cjson.decode(result)	
	local user_id = json_obj.user_id
    local token = json_obj.token
    local sdk = json_obj.sdk
	
    Log("ChanneId==================" .. sdk)

	local verify_callback = function(url, arg, data, size)
		
		self.is_login_verify_ing = false
		if size <= 0 then
			return
		end
		
		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			return
		end
	
		self.uid = ret_t.user.uid
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())

		agent_helper:ShowFloatButton()
	end

	self.is_login_verify_ing = true
	
	local real_url = string.format("%s?spid=%s&device=%s&user_id=%s&token=%s", self.login_verify_url, self:GetSpid(), tostring(PlatformAdapter.GetPhoneUniqueId()),user_id,token)
	Log("start verify login: url=" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)
end

function AgentAdapter:LogoutCallback(result)--注销回调
	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
	return true
end

-- 充值
function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)--购买

	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()
	if self.uid == "" then
		SysMsgCtrl.Instance:ErrorRemind("uid为空，请联系客服")
		return
	end

    local orderid = server_id .. "_".. self.GetSpid() .. "_" .. self.uid .. "_" .. os.time() .. "_" .. role_id

	local param_obj = {}

	param_obj.server_id = tostring(user_vo.plat_server_id)
    param_obj.server_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
    param_obj.role_name = role_vo.name
    param_obj.role_id = tostring(user_vo.cur_role_id)
    param_obj.user_level = tostring(role_vo[OBJ_ATTR.CREATURE_LEVEL]) or "0"
    param_obj.vip_level = tostring(role_vo[OBJ_ATTR.ACTOR_VIP_GRADE]) or "0"

      --帮派名字和账户余额
 	if RoleData.Instance and RoleData.Instance.role_info then
		param_obj.gold = role_vo[OBJ_ATTR.ACTOR_GOLD] or "0"
		param_obj.party_name = RoleData.Instance.role_vo.guild_name or ""
	else
		param_obj.gold = "0"
		param_obj.party_name = ""
	end

    param_obj.order_id = orderid
    param_obj.goods_name = "元宝"
    param_obj.count = amount * 500
    param_obj.amount = amount
    param_obj.goods_id = "1"
    param_obj.paybackUrl = self.pay_verify_url
    param_obj.extras = orderid 
	Log("AgentAdapter:Pay======" .. cjson.encode(param_obj))
	agent_helper:Pay(cjson.encode(param_obj))

end

-- 创建角色上报
function AgentAdapter:ReportOnCreateRole(role_name)
	self:SubmitInfo(0)
end

-- 进入游戏上报
function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(1)
end

--  升级上报
function AgentAdapter:ReportOnRoleLevUp(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(2)
end


function AgentAdapter:SubmitInfo(type)
    local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()

	local info = {}
	info.sub_type = type
	info.server_id = tostring(user_vo.plat_server_id)
	info.server_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
	info.role_name = role_vo.name
    info.role_id = tostring(user_vo.cur_role_id)
    info.user_level = tostring(role_vo[OBJ_ATTR.CREATURE_LEVEL]) or "0"
    info.vip_level = tostring(role_vo[OBJ_ATTR.ACTOR_VIP_GRADE]) or "0"

    --帮派名字和账户余额
 	if RoleData.Instance and RoleData.Instance.role_info then
		info.gold = role_vo[OBJ_ATTR.ACTOR_GOLD] or "0"
		info.party_name = RoleData.Instance.role_vo.guild_name or ""
	else
		info.gold = "0"
		info.party_name = ""
	end

    info.RoleCreateTime = tostring(role_vo.create_time) or "0"

	PlatformBinder:JsonCall("call_agent_submit_extend_data", cjson.encode(info))
	Log("submitInfo=end======" .. cjson.encode(info))
end

--是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end
